@@ -16,13 +16,13 @@
 #' @return Matrix of two columns for the central probability interval
 #'     \code{prob} for all parameters of the model.
 #'
-#' @template example-start
+#' @template start-example
 #' @examples
 #' example_model("single_agent")
 #'
 #' posterior_interval(blrmfit)
 #'
-#' @template example-stop
+#' @template stop-example
 #' @method posterior_interval blrmfit
 #' @aliases posterior_interval
 #' @export
@@ -30,3 +30,10 @@ posterior_interval.blrmfit <- function(object, prob=0.95, ...) {
     post <- as.matrix(object$stanfit, pars=c("mu_log_beta", "tau_log_beta", "rho_log_beta", "mu_eta", "tau_eta", "Sigma_corr_eta", "beta_group", "eta_group"))
     rstantools::posterior_interval(post, prob=prob)
 }
+
+#' @method posterior_interval blrm_trial
+#' @export
+posterior_interval.blrm_trial <- function(object, prob=0.95, ...) {
+    .assert_is_blrm_trial_and_prior_is_set(object)
+    return(posterior_interval.blrmfit(object$blrmfit, prob=prob, ...))
+}
